==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/Prelude/CMonad.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v242	((void*)startLabel+44)
#define FN_LAMBDA236	((void*)startLabel+72)
#define CT_v245	((void*)startLabel+104)
#define CF_LAMBDA236	((void*)startLabel+112)
#define CT_v247	((void*)startLabel+164)
#define FN_LAMBDA237	((void*)startLabel+192)
#define CT_v250	((void*)startLabel+224)
#define CF_LAMBDA237	((void*)startLabel+232)
#define CT_v252	((void*)startLabel+272)
#define CT_v254	((void*)startLabel+340)
#define FN_LAMBDA238	((void*)startLabel+372)
#define CT_v256	((void*)startLabel+396)
#define F0_LAMBDA238	((void*)startLabel+404)
#define CT_v258	((void*)startLabel+440)
#define CT_v260	((void*)startLabel+484)
#define CT_v262	((void*)startLabel+528)
#define CT_v264	((void*)startLabel+572)
#define ST_v249	((void*)startLabel+584)
#define ST_v244	((void*)startLabel+627)
#define ST_v259	((void*)startLabel+673)
#define ST_v257	((void*)startLabel+684)
#define ST_v253	((void*)startLabel+696)
#define ST_v255	((void*)startLabel+709)
#define ST_v246	((void*)startLabel+734)
#define ST_v248	((void*)startLabel+748)
#define ST_v251	((void*)startLabel+768)
#define ST_v241	((void*)startLabel+783)
#define ST_v243	((void*)startLabel+800)
#define ST_v261	((void*)startLabel+823)
#define ST_v263	((void*)startLabel+836)
extern Node TM_Prelude[];
extern Node FN_Prelude_46error[];
extern Node TMSUB_Prelude[];
extern Node FN_Prelude_46_62_62_61[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v242)
,};
Node FN_Prelude_46_95_46return[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_ARG_I2,HEAP_CVAL_I3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,2)
, bytes2word(ZAP_ARG_I2,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(ST_v241)
,	/* CT_v242: (byte 0) */
  HW(2,2)
, 0
,};
Node F0_Prelude_46_95_46return[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46return),2)
, VAPTAG(useLabel(FN_LAMBDA236))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v245)
,	/* FN_LAMBDA236: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v244)
, 0
, useLabel(ST_v243)
,	/* CT_v245: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA236: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA236))
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v247)
,};
Node FN_Prelude_46_95_46_62_62_61[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2)
, bytes2word(HEAP_CVAL_I3,PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,ZAP_ARG_I2,ZAP_ARG_I3,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(ST_v246)
,	/* CT_v247: (byte 0) */
  HW(2,3)
, 0
,};
Node F0_Prelude_46_95_46_62_62_61[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46_62_62_61),3)
, VAPTAG(useLabel(FN_LAMBDA237))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v250)
,	/* FN_LAMBDA237: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v249)
, 0
, useLabel(ST_v248)
,	/* CT_v250: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA237: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA237))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v252)
,};
Node FN_Prelude_46_95_46fail[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3)
, bytes2word(HEAP_ARG,2,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 120005
, useLabel(ST_v251)
,	/* CT_v252: (byte 0) */
  HW(1,2)
, 0
,};
Node F0_Prelude_46_95_46fail[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46fail),2)
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v254)
,};
Node FN_Prelude_46_95_46_62_62[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(3,PUSH_P1,0,PUSH_ARG_I2)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_ARG,1)
, bytes2word(ZAP_ARG_I1,ZAP_ARG_I2,ZAP_ARG_I3,ZAP_STACK_P1)
, bytes2word(3,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 110005
, useLabel(ST_v253)
,	/* CT_v254: (byte 0) */
  HW(2,3)
, 0
,};
Node F0_Prelude_46_95_46_62_62[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46_62_62),3)
, CAPTAG(useLabel(FN_LAMBDA238),1)
, VAPTAG(useLabel(FN_Prelude_46_62_62_61))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v256)
,	/* FN_LAMBDA238: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(ZAP_ARG_I2,NEEDSTACK_I16,PUSH_ARG_I1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110025
, useLabel(ST_v255)
,	/* CT_v256: (byte 0) */
  HW(0,2)
, 0
,	/* F0_LAMBDA238: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA238),2)
, bytes2word(1,0,0,1)
, useLabel(CT_v258)
,};
Node FN_Prelude_46_62_62_61[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50007
, useLabel(ST_v257)
,	/* CT_v258: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46_62_62_61[] = {
  CAPTAG(useLabel(FN_Prelude_46_62_62_61),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v260)
,};
Node FN_Prelude_46_62_62[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50007
, useLabel(ST_v259)
,	/* CT_v260: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46_62_62[] = {
  CAPTAG(useLabel(FN_Prelude_46_62_62),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v262)
,};
Node FN_Prelude_46fail[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,3)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50007
, useLabel(ST_v261)
,	/* CT_v262: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46fail[] = {
  CAPTAG(useLabel(FN_Prelude_46fail),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v264)
,};
Node FN_Prelude_46return[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,4)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50007
, useLabel(ST_v263)
,	/* CT_v264: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46return[] = {
  CAPTAG(useLabel(FN_Prelude_46return),1)
,	/* ST_v249: (byte 0) */
  bytes2word(78,111,32,100)
, bytes2word(101,102,97,117)
, bytes2word(108,116,32,100)
, bytes2word(101,102,105,110)
, bytes2word(105,116,105,111)
, bytes2word(110,32,102,111)
, bytes2word(114,32,99,108)
, bytes2word(97,115,115,32)
, bytes2word(109,101,116,104)
, bytes2word(111,100,32,62)
,	/* ST_v244: (byte 3) */
  bytes2word(62,61,0,78)
, bytes2word(111,32,100,101)
, bytes2word(102,97,117,108)
, bytes2word(116,32,100,101)
, bytes2word(102,105,110,105)
, bytes2word(116,105,111,110)
, bytes2word(32,102,111,114)
, bytes2word(32,99,108,97)
, bytes2word(115,115,32,109)
, bytes2word(101,116,104,111)
, bytes2word(100,32,114,101)
, bytes2word(116,117,114,110)
,	/* ST_v259: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
,	/* ST_v257: (byte 4) */
  bytes2word(46,62,62,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
,	/* ST_v253: (byte 4) */
  bytes2word(62,62,61,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,62,62)
,	/* ST_v255: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,95,46,62)
, bytes2word(62,58,49,49)
, bytes2word(58,50,53,45)
, bytes2word(49,49,58,51)
,	/* ST_v246: (byte 2) */
  bytes2word(50,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,95,46)
,	/* ST_v248: (byte 4) */
  bytes2word(62,62,61,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,62,62)
, bytes2word(61,58,110,111)
,	/* ST_v251: (byte 4) */
  bytes2word(112,111,115,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,102,97)
,	/* ST_v241: (byte 3) */
  bytes2word(105,108,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,95)
, bytes2word(46,114,101,116)
,	/* ST_v243: (byte 4) */
  bytes2word(117,114,110,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,114,101)
, bytes2word(116,117,114,110)
, bytes2word(58,110,111,112)
,	/* ST_v261: (byte 3) */
  bytes2word(111,115,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,102)
,	/* ST_v263: (byte 4) */
  bytes2word(97,105,108,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(114,101,116,117)
, bytes2word(114,110,0,0)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/Prelude/CMonad.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v247	((void*)startLabel+44)
#define FN_LAMBDA241	((void*)startLabel+72)
#define CT_v250	((void*)startLabel+104)
#define CF_LAMBDA241	((void*)startLabel+112)
#define CT_v252	((void*)startLabel+164)
#define FN_LAMBDA242	((void*)startLabel+192)
#define CT_v255	((void*)startLabel+224)
#define CF_LAMBDA242	((void*)startLabel+232)
#define CT_v257	((void*)startLabel+272)
#define CT_v259	((void*)startLabel+340)
#define FN_LAMBDA243	((void*)startLabel+372)
#define CT_v261	((void*)startLabel+396)
#define F0_LAMBDA243	((void*)startLabel+404)
#define CT_v263	((void*)startLabel+440)
#define CT_v265	((void*)startLabel+484)
#define CT_v267	((void*)startLabel+528)
#define CT_v269	((void*)startLabel+572)
#define ST_v254	((void*)startLabel+584)
#define ST_v249	((void*)startLabel+627)
#define ST_v264	((void*)startLabel+673)
#define ST_v262	((void*)startLabel+684)
#define ST_v258	((void*)startLabel+696)
#define ST_v260	((void*)startLabel+709)
#define ST_v251	((void*)startLabel+734)
#define ST_v253	((void*)startLabel+748)
#define ST_v256	((void*)startLabel+768)
#define ST_v246	((void*)startLabel+783)
#define ST_v248	((void*)startLabel+800)
#define ST_v266	((void*)startLabel+823)
#define ST_v268	((void*)startLabel+836)
extern Node TM_Prelude[];
extern Node FN_NHC_46Internal_46_95noMethodError[];
extern Node TMSUB_Prelude[];
extern Node FN_Prelude_46error[];
extern Node FN_Prelude_46_62_62_61[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v247)
,};
Node FN_Prelude_46_95_46return[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_ARG_I2,HEAP_CVAL_I3)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,2)
, bytes2word(ZAP_ARG_I2,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(ST_v246)
,	/* CT_v247: (byte 0) */
  HW(2,2)
, 0
,};
Node F0_Prelude_46_95_46return[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46return),2)
, VAPTAG(useLabel(FN_LAMBDA241))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95noMethodError))
, bytes2word(0,0,0,0)
, useLabel(CT_v250)
,	/* FN_LAMBDA241: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v249)
, 0
, useLabel(ST_v248)
,	/* CT_v250: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA241: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA241))
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v252)
,};
Node FN_Prelude_46_95_46_62_62_61[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2)
, bytes2word(HEAP_CVAL_I3,PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,ZAP_ARG_I2,ZAP_ARG_I3,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(ST_v251)
,	/* CT_v252: (byte 0) */
  HW(2,3)
, 0
,};
Node F0_Prelude_46_95_46_62_62_61[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46_62_62_61),3)
, VAPTAG(useLabel(FN_LAMBDA242))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95noMethodError))
, bytes2word(0,0,0,0)
, useLabel(CT_v255)
,	/* FN_LAMBDA242: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v254)
, 0
, useLabel(ST_v253)
,	/* CT_v255: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA242: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA242))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v257)
,};
Node FN_Prelude_46_95_46fail[] = {
  useLabel(TM_Prelude)
, bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3)
, bytes2word(HEAP_ARG,2,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 120005
, useLabel(ST_v256)
,	/* CT_v257: (byte 0) */
  HW(1,2)
, 0
,};
Node F0_Prelude_46_95_46fail[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46fail),2)
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v259)
,};
Node FN_Prelude_46_95_46_62_62[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(3,PUSH_P1,0,PUSH_ARG_I2)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_ARG,1)
, bytes2word(ZAP_ARG_I1,ZAP_ARG_I2,ZAP_ARG_I3,ZAP_STACK_P1)
, bytes2word(3,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 110005
, useLabel(ST_v258)
,	/* CT_v259: (byte 0) */
  HW(2,3)
, 0
,};
Node F0_Prelude_46_95_46_62_62[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46_62_62),3)
, CAPTAG(useLabel(FN_LAMBDA243),1)
, VAPTAG(useLabel(FN_Prelude_46_62_62_61))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v261)
,	/* FN_LAMBDA243: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(ZAP_ARG_I2,NEEDSTACK_I16,PUSH_ARG_I1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110025
, useLabel(ST_v260)
,	/* CT_v261: (byte 0) */
  HW(0,2)
, 0
,	/* F0_LAMBDA243: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA243),2)
, bytes2word(1,0,0,1)
, useLabel(CT_v263)
,};
Node FN_Prelude_46_62_62_61[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50007
, useLabel(ST_v262)
,	/* CT_v263: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46_62_62_61[] = {
  CAPTAG(useLabel(FN_Prelude_46_62_62_61),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v265)
,};
Node FN_Prelude_46_62_62[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50007
, useLabel(ST_v264)
,	/* CT_v265: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46_62_62[] = {
  CAPTAG(useLabel(FN_Prelude_46_62_62),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v267)
,};
Node FN_Prelude_46fail[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,3)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50007
, useLabel(ST_v266)
,	/* CT_v267: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46fail[] = {
  CAPTAG(useLabel(FN_Prelude_46fail),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v269)
,};
Node FN_Prelude_46return[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,4)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50007
, useLabel(ST_v268)
,	/* CT_v269: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46return[] = {
  CAPTAG(useLabel(FN_Prelude_46return),1)
,	/* ST_v254: (byte 0) */
  bytes2word(78,111,32,100)
, bytes2word(101,102,97,117)
, bytes2word(108,116,32,100)
, bytes2word(101,102,105,110)
, bytes2word(105,116,105,111)
, bytes2word(110,32,102,111)
, bytes2word(114,32,99,108)
, bytes2word(97,115,115,32)
, bytes2word(109,101,116,104)
, bytes2word(111,100,32,62)
,	/* ST_v249: (byte 3) */
  bytes2word(62,61,0,78)
, bytes2word(111,32,100,101)
, bytes2word(102,97,117,108)
, bytes2word(116,32,100,101)
, bytes2word(102,105,110,105)
, bytes2word(116,105,111,110)
, bytes2word(32,102,111,114)
, bytes2word(32,99,108,97)
, bytes2word(115,115,32,109)
, bytes2word(101,116,104,111)
, bytes2word(100,32,114,101)
, bytes2word(116,117,114,110)
,	/* ST_v264: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
,	/* ST_v262: (byte 4) */
  bytes2word(46,62,62,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
,	/* ST_v258: (byte 4) */
  bytes2word(62,62,61,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,62,62)
,	/* ST_v260: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,95,46,62)
, bytes2word(62,58,49,49)
, bytes2word(58,50,53,45)
, bytes2word(49,49,58,51)
,	/* ST_v251: (byte 2) */
  bytes2word(50,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,95,46)
,	/* ST_v253: (byte 4) */
  bytes2word(62,62,61,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,62,62)
, bytes2word(61,58,110,111)
,	/* ST_v256: (byte 4) */
  bytes2word(112,111,115,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,102,97)
,	/* ST_v246: (byte 3) */
  bytes2word(105,108,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,95)
, bytes2word(46,114,101,116)
,	/* ST_v248: (byte 4) */
  bytes2word(117,114,110,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,114,101)
, bytes2word(116,117,114,110)
, bytes2word(58,110,111,112)
,	/* ST_v266: (byte 3) */
  bytes2word(111,115,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,102)
,	/* ST_v268: (byte 4) */
  bytes2word(97,105,108,0)
, bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(114,101,116,117)
, bytes2word(114,110,0,0)
,};
